<?php

namespace Drupal\commerce_payone\Plugin\Commerce\PaymentMethodType;

use Drupal\commerce_payment\Entity\PaymentMethodInterface;
use Drupal\commerce_payment\Plugin\Commerce\PaymentMethodType\PaymentMethodTypeBase;
use Drupal\entity\BundleFieldDefinition;

/**
 * Provides the payment method type for Payone Sepa payments.
 *
 * @CommercePaymentMethodType(
 *   id = "commerce_payone_invoice",
 *   label = @Translation("Payone Invoice"),
 *   create_label = @Translation("Invoice"),
 * )
 */
class InvoiceMethod extends PaymentMethodTypeBase {

  /**
   * {@inheritdoc}
   */
  public function buildLabel(PaymentMethodInterface $payment_method) {
    if (!$payment_method->getBillingProfile()->address->first()) {
      return $this->t('Invoice');
    }
    $address = $payment_method->getBillingProfile()->address->first();
    $company = $address->getOrganization();
    $has_company = !empty($company);

    $label = $has_company ?
      'Invoice to @company, @given_name @family_name, @street, @plz @city' :
      'Invoice to @given_name @family_name, @street, @plz @city';
    $translation_args = [
      '@given_name' => $address->getGivenName(),
      '@family_name' => $address->getFamilyName(),
      '@street' => $address->getAddressLine1() . ' ' . $address->getAddressLine2(),
      '@plz' => $address->getPostalCode(),
      '@city' => $address->getLocality(),
    ];
    if ($has_company) {
      $translation_args['@company'] = $company;
    }
    return $this->t($label, $translation_args);
  }

  /**
   * {@inheritdoc}
   */
  public function buildFieldDefinitions() {
    return [];
  }

}
